@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -97,16 +97,26 @@ from .deploy import (
     FileInfo,
     ZipInfo,
 )
-from .domain import AuthorizedDomain
+from .domain import (
+    AuthorizedDomain,
+)
 from .domain_mapping import (
     DomainMapping,
     ResourceRecord,
     SslSettings,
 )
-from .firewall import FirewallRule
-from .instance import Instance
-from .location import LocationMetadata
-from .network_settings import NetworkSettings
+from .firewall import (
+    FirewallRule,
+)
+from .instance import (
+    Instance,
+)
+from .location import (
+    LocationMetadata,
+)
+from .network_settings import (
+    NetworkSettings,
+)
 from .operation import (
     CreateVersionMetadataV1,
     OperationMetadataV1,
